@@ -3,7 +3,7 @@ package Alien::hiredis;
 use strict;
 use warnings;
 
-our $VERSION = '0.012'; # TRIAL
+our $VERSION = '0.015'; # TRIAL
 
 use parent 'Alien::Base';
 
@@ -35,6 +35,10 @@ This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
+Bundled L<hiredis|https://github.com/redis/hiredis> library for
+share installs is licensed under the (three-clause) BSD License.
+See its F<COPYING> file for details.
+
 =head1 SEE ALSO
 
 L<Redis::hiredis>, L<Protocol::Redis::XS>
